@@ -1,19 +1,21 @@
 import json
 
-def get_routing_key(method, topic):
-    return "{topic}.{method}".format(topic=topic, method=method)
+def get_routing_key(method, topic, status):
+    return "{topic}.{method}.{status}".format(topic=topic, method=method, status=status)
 
 class Message(object):
-    def __init__(self, method, topic, body):
+    def __init__(self, method, topic, status, body):
         self.method = method
         self.topic = topic
+        self.status = status
         self.body = body
-        self.routing_key = get_routing_key(method, topic)
+        self.routing_key = get_routing_key(method, topic, status)
 
     def get_dict(self):
         return {
             "method": self.method,
             "topic": self.topic,
+            "status": self.status,
             "body": self.body
         }
 
